@@ -24,7 +24,7 @@ __version__ = "$Id: action.py 312 2007-04-09 19:45:49Z wrobel $"
 #
 #-------------------------------------------------------------------------------
 
-import sys
+import os, sys
 
 from   layman.db                import DB, RemoteDB
 
@@ -289,17 +289,24 @@ class Info:
     def run(self):
         ''' Print information about the selected overlays.'''
 
+        result = 0
+
         for i in self.selection:
             overlay = self.rdb.select(i)
-            # Is the overlay supported?
-            OUT.info(overlay.__str__(), 1)
-            if not overlay.is_official():
-                OUT.warn('*** This is no official gentoo overlay ***\n', 1)
-            if not overlay.is_supported():
-                OUT.error('*** You are lacking the necessary tools to install t'
-                          'his overlay ***\n')
 
-        return 0
+            if overlay:
+                # Is the overlay supported?
+                OUT.info(overlay.__str__(), 1)
+                if not overlay.is_official():
+                    OUT.warn('*** This is no official gentoo overlay ***\n', 1)
+                if not overlay.is_supported():
+                    OUT.error('*** You are lacking the necessary tools to install t'
+                              'his overlay ***\n')
+            else:
+                OUT.warn('Overlay "' + i + '" does not exist!', 2)
+                result = 1
+
+        return result
 
 #===============================================================================
 #
@@ -465,6 +472,15 @@ class Actions:
 
         result = 0
 
+        # Set the umask
+        umask = config['umask']
+        try:
+            new_umask = int(umask, 8)
+            old_umask = os.umask(new_umask)
+        except Exception, error:
+            OUT.die('Failed setting to umask "' + umask + '"!\nError was: ' 
+                    + str(error))
+
         for i in self.actions:
 
             OUT.debug('Checking for action', 7)
@@ -472,6 +488,8 @@ class Actions:
             if i[0] in config.keys():
                 result += i[1](config).run()
 
+        # Reset umask
+        os.umask(old_umask)
 
         if not result:
             sys.exit(0)
