@@ -18,7 +18,7 @@
 '''Should work with any version of Bzr equal to or better than 0.7 --
  caution: tested only with 0.8 and 0.8.2...'''
 
-__version__ = "$Id$"
+__version__ = "$Id: bzr.py 236 2006-09-05 20:39:37Z wrobel $"
 
 #===============================================================================
 #
@@ -29,8 +29,6 @@ __version__ = "$Id$"
 from   layman.utils             import path
 from   layman.overlays.overlay  import Overlay
 
-from   layman.debug             import OUT
-
 #===============================================================================
 #
 # Class BzrOverlay
@@ -42,22 +40,27 @@ class BzrOverlay(Overlay):
 
     type = 'Bzr'
 
-    binary_command  = '/usr/bin/bzr' 
-    
+    binary_command  = '/usr/bin/bzr'
+
     def add(self, base):
+        '''Add overlay.'''
 
         self.supported()
 
-        return self.cmd(self.binary_command + ' get ' + self.src + '/ ' + \
-                        path([base, self.name]))
+        return self.cmd(self.binary_command + ' get "' + self.src + '/" "' +\
+                        path([base, self.name]) + '"')
 
     def sync(self, base):
+        '''Sync overlay.'''
 
         self.supported()
 
-        return self.cmd('cd ' + path([base, self.name]) + ' && ' + \
-                        self.binary_command + ' pull --overwrite ' + self.src)
+        return self.cmd('cd "' + path([base, self.name]) + '" && ' +          \
+                        self.binary_command + ' pull --overwrite "' + self.src \
+                        + '"')
 
     def supported(self):
+        '''Overlay type supported?'''
 
-        return Overlay.supported(self, [(self.binary_command,  'bzr', 'dev-util/bzr'),])
+        return Overlay.supported(self, [(self.binary_command,  'bzr',
+                                         'dev-util/bzr'),])
