@@ -40,9 +40,9 @@ class CvsOverlay(Overlay):
 
     binary = '/usr/bin/cvs'
 
-    def __init__(self, xml, ignore = False):
+    def __init__(self, xml, ignore = 0, quiet = False):
 
-        Overlay.__init__(self, xml, ignore)
+        Overlay.__init__(self, xml, ignore, quiet)
 
         if '&subpath' in self.data.keys():
             self.subpath = self.data['&subpath']
